@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "utop" "2.16.0"
+(define-package "utop" "20250722.1319"
   "Universal toplevel for OCaml."
   '((emacs  "26")
     (tuareg "2.2.0"))
   :url "https://github.com/ocaml-community/utop"
   :commit "bd6a1546e5c73c7a626e456fac5e81027106e4d6"
-  :revdesc "2.16.0-0-gbd6a1546e5c7"
+  :revdesc "bd6a1546e5c7"
   :keywords '("ocaml" "languages")
   :authors '(("Jeremie Dimino" . "jeremie@dimino.org"))
   :maintainers '(("Jeremie Dimino" . "jeremie@dimino.org")))
